@@ -26,10 +26,10 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-fno-strict-overflow -Wsign-compare '
-           '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
+           '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
            '-mbranch-protection=standard -fexceptions '
            '-mbranch-protection=standard -fexceptions '
-           '-mbranch-protection=standard -fexceptions   -O3',
+           '-mbranch-protection=standard   -O3',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CODECS_COMMON_HEADERS': '/builddir/build/BUILD/Python-3.12.12/Modules/cjkcodecs/multibytecodec.h '
@@ -37,7 +37,7 @@ build_time_vars = {'ABIFLAGS': '',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-mbranch-protection=standard -fexceptions',
+ 'CONFIGURE_CFLAGS': '-fexceptions -mbranch-protection=standard',
  'CONFIGURE_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                             '-grecord-gcc-switches -pipe -Wall '
                             '-Wno-complain-wrong-lang -Werror=format-security '
@@ -93,7 +93,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'build_alias=aarch64-redhat-linux-gnu' "
                 "'host_alias=aarch64-redhat-linux-gnu' "
                 "'PKG_CONFIG_PATH=:/usr/lib64/pkgconfig:/usr/share/pkgconfig' "
-                "'CC=gcc' 'CFLAGS=-mbranch-protection=standard -fexceptions  ' "
+                "'CC=gcc' 'CFLAGS=-fexceptions -mbranch-protection=standard  ' "
                 "'LDFLAGS= ' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
@@ -674,13 +674,13 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
+                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
                     '-mbranch-protection=standard -fexceptions '
                     '-mbranch-protection=standard -fexceptions '
-                    '-mbranch-protection=standard -fexceptions   -O3 '
-                    '-flto=auto -ffat-lto-objects -fexceptions -g '
-                    '-grecord-gcc-switches -pipe -Wall '
-                    '-Wno-complain-wrong-lang -Werror=format-security '
+                    '-mbranch-protection=standard   -O3 -flto=auto '
+                    '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
+                    '-pipe -Wall -Wno-complain-wrong-lang '
+                    '-Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -713,9 +713,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBHACL_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.12/Modules/_hacl/include '
                    '-D_BSD_SOURCE -D_DEFAULT_SOURCE -fno-strict-overflow '
                    '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
+                   '-fexceptions -mbranch-protection=standard -fexceptions '
                    '-mbranch-protection=standard -fexceptions '
-                   '-mbranch-protection=standard -fexceptions '
-                   '-mbranch-protection=standard -fexceptions   -O3 -flto=auto '
+                   '-mbranch-protection=standard   -O3 -flto=auto '
                    '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
                    '-pipe -Wall -Wno-complain-wrong-lang '
                    '-Werror=format-security '
@@ -752,13 +752,13 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
                     '-fno-strict-overflow -Wsign-compare '
-                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
+                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
                     '-mbranch-protection=standard -fexceptions '
                     '-mbranch-protection=standard -fexceptions '
-                    '-mbranch-protection=standard -fexceptions   -O3 '
-                    '-flto=auto -ffat-lto-objects -fexceptions -g '
-                    '-grecord-gcc-switches -pipe -Wall '
-                    '-Wno-complain-wrong-lang -Werror=format-security '
+                    '-mbranch-protection=standard   -O3 -flto=auto '
+                    '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
+                    '-pipe -Wall -Wno-complain-wrong-lang '
+                    '-Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1116,8 +1116,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -mbranch-protection=standard '
-        '-fexceptions',
+ 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+        '-mbranch-protection=standard',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1153,9 +1153,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
-                             '-mbranch-protection=standard -fexceptions '
-                             '-mbranch-protection=standard -fexceptions '
-                             '-mbranch-protection=standard -fexceptions   -O3 '
+                             '-fexceptions -mbranch-protection=standard '
+                             '-fexceptions -mbranch-protection=standard '
+                             '-fexceptions -mbranch-protection=standard   -O3 '
                              '-flto=auto -ffat-lto-objects -fexceptions -g '
                              '-grecord-gcc-switches -pipe -Wall '
                              '-Wno-complain-wrong-lang -Werror=format-security '
@@ -1192,10 +1192,10 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I/builddir/build/BUILD/Python-3.12.12/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
+              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
               '-mbranch-protection=standard -fexceptions '
               '-mbranch-protection=standard -fexceptions '
-              '-mbranch-protection=standard -fexceptions   -O3',
+              '-mbranch-protection=standard   -O3',
  'PY_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                      '-grecord-gcc-switches -pipe -Wall '
                      '-Wno-complain-wrong-lang -Werror=format-security '
@@ -1227,10 +1227,10 @@ build_time_vars = {'ABIFLAGS': '',
                      '-I/builddir/build/BUILD/Python-3.12.12/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
+                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
                    '-mbranch-protection=standard -fexceptions '
                    '-mbranch-protection=standard -fexceptions '
-                   '-mbranch-protection=standard -fexceptions   -O3 -flto=auto '
+                   '-mbranch-protection=standard   -O3 -flto=auto '
                    '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
                    '-pipe -Wall -Wno-complain-wrong-lang '
                    '-Werror=format-security '
@@ -1306,11 +1306,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
+                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
                         '-mbranch-protection=standard -fexceptions '
                         '-mbranch-protection=standard -fexceptions '
-                        '-mbranch-protection=standard -fexceptions   -O3 '
-                        '-flto=auto -ffat-lto-objects -fexceptions -g '
+                        '-mbranch-protection=standard   -O3 -flto=auto '
+                        '-ffat-lto-objects -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Wno-complain-wrong-lang -Werror=format-security '
                         '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
